pub trait FromBytes: Sized
{
   type Error;

   fn from_bytes(bytes: &[u8]) -> Result<Parsed<Self>, Self::Error>;
}

pub trait IntoBytes
{
   type Error;

   fn into_bytes(self, buffer: &mut [u8]) -> Result<usize, Self::Error>;
}

pub trait FromBits: Sized
{
   type Error;

   fn from_bits(bytes: &[u8], mask: &[u8]) -> Result<Self, Self::Error>;
}

pub trait IntoBits
{
   type Error;

   fn into_bits(self, bytes: &mut [u8], mask: &[u8]) -> Result<(), Self::Error>;
}


pub struct Parsed<T>
{
   pub bytes_read: usize,
   pub data: T
}

impl<T> Parsed<T>
{
   pub fn new(bytes_read: usize, data: T) -> Self
   {
      Parsed
      {
         bytes_read,
         data
      }
   }
}
